@@ -24,7 +24,6 @@ from requests_mock.contrib import fixture as rm_fixture
 import six
 from six.moves.urllib.parse import urlparse
 import tempfile
-import urllib3
 import zlib
 
 from oslo_concurrency import processutils
@@ -139,10 +138,10 @@ class TestImageUploadManager(base.TestCase):
             manager.get_push_destination({'push_destination': None})
         )
 
-    def test_get_uploader_docker(self):
+    def test_get_uploader_python(self):
         manager = image_uploader.ImageUploadManager(self.filelist)
-        uploader = manager.get_uploader('docker')
-        assert isinstance(uploader, image_uploader.DockerImageUploader)
+        uploader = manager.get_uploader('python')
+        assert isinstance(uploader, image_uploader.PythonImageUploader)
 
     def test_get_uploader_skopeo(self):
         manager = image_uploader.ImageUploadManager(self.filelist)
@@ -271,63 +270,63 @@ class TestBaseImageUploader(base.TestCase):
         self.assertEqual(
             ('docker.io/t/foo', 'a'),
             image_uploader.discover_tag_from_inspect(
-                ('docker.io/t/foo', 'rdo_version'))
+                (self.uploader, 'docker.io/t/foo', 'rdo_version'))
         )
 
         # templated labels -> tag
         self.assertEqual(
             ('docker.io/t/foo', '1.0.0-20180125'),
             image_uploader.discover_tag_from_inspect(
-                ('docker.io/t/foo', '{release}-{version}'))
+                (self.uploader, 'docker.io/t/foo', '{release}-{version}'))
         )
 
         # simple label -> tag with fallback
         self.assertEqual(
             ('docker.io/t/foo', 'a'),
             image_uploader.discover_tag_from_inspect(
-                ('docker.io/t/foo:a', 'bar'))
+                (self.uploader, 'docker.io/t/foo:a', 'bar'))
         )
 
         # templated labels -> tag with fallback
         self.assertEqual(
             ('docker.io/t/foo', 'a'),
             image_uploader.discover_tag_from_inspect(
-                ('docker.io/t/foo:a', '{releases}-{versions}'))
+                (self.uploader, 'docker.io/t/foo:a', '{releases}-{versions}'))
         )
 
         # Invalid template
         self.assertRaises(
             ImageUploaderException,
             image_uploader.discover_tag_from_inspect,
-            ('docker.io/t/foo', '{release}-{version')
+            (self.uploader, 'docker.io/t/foo', '{release}-{version')
         )
 
         # Missing label in template
         self.assertRaises(
             ImageUploaderException,
             image_uploader.discover_tag_from_inspect,
-            ('docker.io/t/foo', '{releases}-{version}')
+            (self.uploader, 'docker.io/t/foo', '{releases}-{version}')
         )
 
         # no tag_from_label specified
         self.assertRaises(
             ImageUploaderException,
             image_uploader.discover_tag_from_inspect,
-            ('docker.io/t/foo', None)
+            (self.uploader, 'docker.io/t/foo', None)
         )
 
         # missing RepoTags entry
         self.assertRaises(
             ImageUploaderException,
             image_uploader.discover_tag_from_inspect,
-            ('docker.io/t/foo', 'build_version')
+            (self.uploader, 'docker.io/t/foo', 'build_version')
         )
 
         # missing Labels entry
         self.assertRaises(
             ImageUploaderException,
             image_uploader.discover_tag_from_inspect,
-            ('docker.io/t/foo', 'version')
+            (self.uploader, 'docker.io/t/foo', 'version')
         )
 
         # inspect call failed
@@ -335,7 +334,7 @@ class TestBaseImageUploader(base.TestCase):
         self.assertRaises(
             ImageUploaderException,
             image_uploader.discover_tag_from_inspect,
-            ('docker.io/t/foo', 'rdo_version')
+            (self.uploader, 'docker.io/t/foo', 'rdo_version')
         )
 
     @mock.patch('concurrent.futures.ThreadPoolExecutor')
@@ -361,9 +360,9 @@ class TestBaseImageUploader(base.TestCase):
         mock_pool.return_value.map.assert_called_once_with(
             image_uploader.discover_tag_from_inspect,
             [
-                ('docker.io/t/foo', 'rdo_release'),
-                ('docker.io/t/bar', 'rdo_release'),
-                ('docker.io/t/baz', 'rdo_release')
+                (self.uploader, 'docker.io/t/foo', 'rdo_release'),
+                (self.uploader, 'docker.io/t/bar', 'rdo_release'),
+                (self.uploader, 'docker.io/t/baz', 'rdo_release')
             ])
 
     @mock.patch('tripleo_common.image.image_uploader.'
@@ -389,7 +388,7 @@ class TestBaseImageUploader(base.TestCase):
 
     def test_authenticate(self):
         req = self.requests
-        auth = image_uploader.BaseImageUploader.authenticate
+        auth = self.uploader.authenticate
         url1 = urlparse('docker://docker.io/t/nova-api:latest')
 
         # no auth required
@@ -421,7 +420,7 @@ class TestBaseImageUploader(base.TestCase):
 
     def test_authenticate_with_no_service(self):
         req = self.requests
-        auth = image_uploader.BaseImageUploader.authenticate
+        auth = self.uploader.authenticate
         url1 = urlparse('docker://docker.io/t/nova-api:latest')
 
         headers = {
@@ -633,335 +632,6 @@ class TestBaseImageUploader(base.TestCase):
         )
 
 
-class TestDockerImageUploader(base.TestCase):
-
-    def setUp(self):
-        super(TestDockerImageUploader, self).setUp()
-        self.uploader = image_uploader.DockerImageUploader()
-        self.uploader._push.retry.sleep = mock.Mock()
-        self.uploader._pull.retry.sleep = mock.Mock()
-        self.uploader._inspect.retry.sleep = mock.Mock()
-
-        self.patcher = mock.patch('tripleo_common.image.image_uploader.Client')
-        self.dockermock = self.patcher.start()
-
-    def tearDown(self):
-        super(TestDockerImageUploader, self).tearDown()
-        self.patcher.stop()
-
-    @mock.patch('tripleo_common.image.image_uploader.'
-                'BaseImageUploader.authenticate')
-    @mock.patch('tripleo_common.image.image_uploader.'
-                'BaseImageUploader._inspect')
-    def test_upload_image(self, mock_inspect, mock_auth):
-        result1 = {
-            'Digest': 'a'
-        }
-        result2 = {
-            'Digest': 'b'
-        }
-        mock_inspect.side_effect = [result1, result2]
-
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
-        tag = 'latest'
-        push_destination = 'localhost:8787'
-        push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
-
-        self.assertEqual(
-            ['docker.io/tripleomaster/heat-docker-agents-centos:latest',
-             'localhost:8787/tripleomaster/heat-docker-agents-centos:latest'],
-            self.uploader.upload_image(image_uploader.UploadTask(
-                image + ':' + tag,
-                None,
-                push_destination,
-                None,
-                None,
-                None,
-                False,
-                'full')
-            )
-        )
-
-        self.dockermock.assert_called_once_with(
-            base_url='unix://var/run/docker.sock', version='auto')
-
-        self.dockermock.return_value.pull.assert_called_once_with(
-            image, tag=tag, stream=True)
-        self.dockermock.return_value.tag.assert_called_once_with(
-            image=image + ':' + tag,
-            repository=push_image,
-            tag=tag, force=True)
-        self.dockermock.return_value.push.assert_called_once_with(
-            push_image,
-            tag=tag, stream=True)
-
-    @mock.patch('tripleo_common.image.image_uploader.'
-                'BaseImageUploader.authenticate')
-    @mock.patch('tripleo_common.image.image_uploader.'
-                'BaseImageUploader._inspect')
-    def test_upload_image_existing(self, mock_inspect, mock_auth):
-        mock_inspect.return_value = {
-            'Digest': 'a'
-        }
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
-        tag = 'latest'
-        push_destination = 'localhost:8787'
-
-        self.assertEqual(
-            [],
-            self.uploader.upload_image(image_uploader.UploadTask(
-                image + ':' + tag,
-                None,
-                push_destination,
-                None,
-                None,
-                None,
-                False,
-                'full')
-            )
-        )
-
-        # both digests are the same, no pull/push
-        self.dockermock.assert_not_called()
-        self.dockermock.return_value.pull.assert_not_called()
-        self.dockermock.return_value.tag.assert_not_called()
-        self.dockermock.return_value.push.assert_not_called()
-
-    @mock.patch('tripleo_common.image.image_uploader.'
-                'BaseImageUploader.authenticate')
-    @mock.patch('tripleo_common.image.image_uploader.'
-                'BaseImageUploader._inspect')
-    @mock.patch('tripleo_common.actions.'
-                'ansible.AnsiblePlaybookAction', autospec=True)
-    def test_modify_upload_image(self, mock_ansible, mock_inspect, mock_auth):
-        mock_inspect.side_effect = ImageNotFoundException()
-        mock_ansible.return_value.run.return_value = {}
-
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
-        tag = 'latest'
-        append_tag = 'modify-123'
-        push_destination = 'localhost:8787'
-        push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
-        playbook = [{
-            'tasks': [{
-                'import_role': {
-                    'name': 'add-foo-plugin'
-                },
-                'name': 'Import role add-foo-plugin',
-                'vars': {
-                    'target_image': '%s:%s' % (push_image, tag),
-                    'modified_append_tag': append_tag,
-                    'source_image': '%s:%s' % (image, tag),
-                    'foo_version': '1.0.1',
-                    'container_build_tool': 'docker'
-                }
-            }],
-            'hosts': 'localhost'
-        }]
-
-        # test response for a partial cleanup
-        self.assertEqual(
-            ['docker.io/tripleomaster/heat-docker-agents-centos:latest'],
-            self.uploader.upload_image(image_uploader.UploadTask(
-                image + ':' + tag,
-                None,
-                push_destination,
-                append_tag,
-                'add-foo-plugin',
-                {'foo_version': '1.0.1'},
-                False,
-                'partial')
-            )
-        )
-
-        self.dockermock.assert_called_once_with(
-            base_url='unix://var/run/docker.sock', version='auto')
-
-        self.dockermock.return_value.pull.assert_called_once_with(
-            image, tag=tag, stream=True)
-        mock_ansible.assert_called_once_with(
-            playbook=playbook,
-            work_dir=mock.ANY,
-            verbosity=1,
-            extra_env_variables=mock.ANY,
-            override_ansible_cfg=(
-                "[defaults]\n"
-                "stdout_callback=yaml\n"
-            )
-        )
-        self.dockermock.return_value.tag.assert_not_called()
-        self.dockermock.return_value.push.assert_called_once_with(
-            push_image,
-            tag=tag + append_tag,
-            stream=True)
-
-    @mock.patch('tripleo_common.image.image_uploader.'
-                'BaseImageUploader.authenticate')
-    @mock.patch('tripleo_common.image.image_uploader.'
-                'BaseImageUploader._inspect')
-    @mock.patch('tripleo_common.actions.'
-                'ansible.AnsiblePlaybookAction', autospec=True)
-    def test_modify_image_failed(self, mock_ansible, mock_inspect, mock_auth):
-        mock_inspect.side_effect = ImageNotFoundException()
-
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
-        tag = 'latest'
-        append_tag = 'modify-123'
-        push_destination = 'localhost:8787'
-        error = processutils.ProcessExecutionError(
-            '', 'ouch', -1, 'ansible-playbook')
-        mock_ansible.return_value.run.side_effect = error
-
-        self.assertRaises(
-            ImageUploaderException,
-            self.uploader.upload_image, image_uploader.UploadTask(
-                image + ':' + tag, None, push_destination,
-                append_tag, 'add-foo-plugin', {'foo_version': '1.0.1'},
-                False, 'full')
-        )
-
-        self.dockermock.assert_called_once_with(
-            base_url='unix://var/run/docker.sock', version='auto')
-
-        self.dockermock.return_value.pull.assert_called_once_with(
-            image, tag=tag, stream=True)
-        self.dockermock.return_value.tag.assert_not_called()
-        self.dockermock.return_value.push.assert_not_called()
-
-    @mock.patch('subprocess.Popen')
-    @mock.patch('tripleo_common.actions.'
-                'ansible.AnsiblePlaybookAction', autospec=True)
-    def test_modify_upload_image_dry_run(self, mock_ansible, mock_popen):
-        mock_process = mock.Mock()
-        mock_popen.return_value = mock_process
-
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
-        tag = 'latest'
-        append_tag = 'modify-123'
-        push_destination = 'localhost:8787'
-
-        result = self.uploader.upload_image(image_uploader.UploadTask(
-            image + ':' + tag,
-            None,
-            push_destination,
-            append_tag,
-            'add-foo-plugin',
-            {'foo_version': '1.0.1'},
-            True,
-            'full')
-        )
-
-        self.dockermock.assert_not_called()
-        mock_ansible.assert_not_called()
-        mock_process.communicate.assert_not_called()
-        self.assertEqual([], result)
-
-    @mock.patch('tripleo_common.image.image_uploader.'
-                'BaseImageUploader.authenticate')
-    @mock.patch('tripleo_common.image.image_uploader.'
-                'BaseImageUploader._inspect')
-    @mock.patch('tripleo_common.actions.'
-                'ansible.AnsiblePlaybookAction', autospec=True)
-    def test_modify_image_existing(self, mock_ansible, mock_inspect,
-                                   mock_auth):
-        mock_inspect.return_value = {'Digest': 'a'}
-
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
-        tag = 'latest'
-        append_tag = 'modify-123'
-        push_destination = 'localhost:8787'
-
-        result = self.uploader.upload_image(image_uploader.UploadTask(
-            image + ':' + tag,
-            None,
-            push_destination,
-            append_tag,
-            'add-foo-plugin',
-            {'foo_version': '1.0.1'},
-            False,
-            'full')
-        )
-
-        self.dockermock.assert_not_called()
-        mock_ansible.assert_not_called()
-
-        self.assertEqual([], result)
-
-    def test_pull_retry(self):
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
-
-        dockerc = self.dockermock.return_value
-        dockerc.pull.side_effect = [
-            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
-            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
-            ['{"error": "ouch"}'],
-            ['{"error": "ouch"}'],
-            ['{"status": "done"}']
-        ]
-        self.uploader._pull(dockerc, image)
-
-        self.assertEqual(dockerc.pull.call_count, 5)
-        dockerc.pull.assert_has_calls([
-            mock.call(image, tag=None, stream=True)
-        ])
-
-    def test_pull_retry_failure(self):
-        image = 'docker.io/tripleomaster/heat-docker-agents-centos'
-
-        dockerc = self.dockermock.return_value
-        dockerc.pull.side_effect = [
-            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
-            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
-            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
-            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
-            urllib3.exceptions.ReadTimeoutError('p', '/foo', 'ouch'),
-        ]
-        self.assertRaises(urllib3.exceptions.ReadTimeoutError,
-                          self.uploader._pull, dockerc, image)
-
-        self.assertEqual(dockerc.pull.call_count, 5)
-        dockerc.pull.assert_has_calls([
-            mock.call(image, tag=None, stream=True)
-        ])
-
-    def test_push_retry(self):
-        image = 'docker.io/tripleoupstream/heat-docker-agents-centos'
-
-        dockerc = self.dockermock.return_value
-        dockerc.push.side_effect = [
-            ['{"error": "ouch"}'],
-            ['{"error": "ouch"}'],
-            ['{"error": "ouch"}'],
-            ['{"error": "ouch"}'],
-            ['{"status": "done"}']
-        ]
-        self.uploader._push(dockerc, image)
-
-        self.assertEqual(dockerc.push.call_count, 5)
-        dockerc.push.assert_has_calls([
-            mock.call(image, tag=None, stream=True)
-        ])
-
-    def test_push_retry_failure(self):
-        image = 'docker.io/tripleoupstream/heat-docker-agents-centos'
-
-        dockerc = self.dockermock.return_value
-        dockerc.push.side_effect = [
-            ['{"error": "ouch"}'],
-            ['{"error": "ouch"}'],
-            ['{"error": "ouch"}'],
-            ['{"error": "ouch"}'],
-            ['{"error": "ouch"}'],
-        ]
-        self.assertRaises(ImageUploaderException,
-                          self.uploader._push, dockerc, image)
-
-        self.assertEqual(dockerc.push.call_count, 5)
-        dockerc.push.assert_has_calls([
-            mock.call(image, tag=None, stream=True)
-        ])
-
-
 class TestSkopeoImageUploader(base.TestCase):
 
     def setUp(self):
@@ -1333,6 +1003,68 @@ class TestPythonImageUploader(base.TestCase):
             target_session=target_session
         )
 
+    @mock.patch('tripleo_common.image.image_uploader.'
+                'PythonImageUploader.authenticate')
+    @mock.patch('tripleo_common.image.image_uploader.'
+                'PythonImageUploader._fetch_manifest')
+    @mock.patch('tripleo_common.image.image_uploader.'
+                'PythonImageUploader._cross_repo_mount')
+    @mock.patch('tripleo_common.image.image_uploader.'
+                'PythonImageUploader._copy_registry_to_registry')
+    def test_insecure_registry(
+            self, _copy_registry_to_registry, _cross_repo_mount,
+            _fetch_manifest, authenticate):
+        target_session = mock.Mock()
+        source_session = mock.Mock()
+        authenticate.side_effect = [
+            target_session,
+            source_session
+        ]
+        manifest = json.dumps({
+            'config': {
+                'digest': 'sha256:1234',
+            },
+            'layers': [
+                {'digest': 'sha256:aaa'},
+                {'digest': 'sha256:bbb'},
+                {'digest': 'sha256:ccc'}
+            ],
+        })
+        _fetch_manifest.return_value = manifest
+
+        image = '192.0.2.0:8787/tripleomaster/heat-docker-agents-centos'
+        tag = 'latest'
+        push_destination = 'localhost:8787'
+        # push_image = 'localhost:8787/tripleomaster/heat-docker-agents-centos'
+        task = image_uploader.UploadTask(
+            image_name=image + ':' + tag,
+            pull_source=None,
+            push_destination=push_destination,
+            append_tag=None,
+            modify_role=None,
+            modify_vars=None,
+            dry_run=False,
+            cleanup='full'
+        )
+
+        self.assertEqual(
+            [],
+            self.uploader.upload_image(task)
+        )
+        source_url = urlparse('docker://192.0.2.0:8787/tripleomaster/'
+                              'heat-docker-agents-centos:latest')
+        target_url = urlparse('docker://localhost:8787/tripleomaster/'
+                              'heat-docker-agents-centos:latest')
+
+        authenticate.assert_has_calls([
+            mock.call(
+                target_url
+            ),
+            mock.call(
+                source_url
+            ),
+        ])
+
     @mock.patch('tripleo_common.image.image_uploader.'
                 'PythonImageUploader.authenticate')
     @mock.patch('tripleo_common.image.image_uploader.'
